/* collections.h - Common definitions for maps, lists and sets.
 *
 * Copyright (C) 2001  Oskar Liljeblad
 *
 * This file is part of the file renaming utilities (renameutils)
 * and regex-markup.
 *
 * This software is copyrighted work licensed under the terms of the
 * GNU General Public License. Please consult the file `COPYING' for
 * details.
 */

#ifndef __MAP_H__
#define __MAP_H__

/* POSIX */
#if HAVE_STDINT_H
#include <stdint.h>
#endif

typedef int32_t (*CompareFunc)(const void *, const void *);

#endif
